@@ -47,6 +47,7 @@
 #'   separate for x- and y-axis).
 #'
 #' @export
+#' @importFrom graphics plot title rect axis abline points
 #'
 #' @return
 #' None.
@@ -87,6 +88,7 @@ grayplot <-
         function(x, y, ..., type="p", hlines, hlines.col, hlines.lty, hlines.lwd,
                  vlines, vlines.col, vlines.lty, vlines.lwd,
                  xat, yat, bgcolor="gray80", xaxt="n", yaxt="n",
+                 col.lab="black",
                  xlab, ylab, xname, yname,
                  las=1, mgp.x=c(2.6, 0.5, 0), mgp.y=c(2.6, 0.5, 0),
                  v_over_h=FALSE)
@@ -132,8 +134,8 @@ grayplot <-
                 plot(x, y, ..., type="n", xaxt="n", yaxt="n", xlab="", ylab="")
 
             # axis titles
-            title(xlab=xlab, mgp=mgp.x)
-            title(ylab=ylab, mgp=mgp.y)
+            title(xlab=xlab, mgp=mgp.x, col.lab=col.lab)
+            title(ylab=ylab, mgp=mgp.y, col.lab=col.lab)
 
             # add gray rectangle
             u <- par("usr")
