@@ -28,4 +28,4 @@
 #' color
 revrainbow <-
     function(n=256, ...)
-    rev(rainbow(start=0, end=2/3, n=n, ...))
+    rev(grDevices::rainbow(start=0, end=2/3, n=n, ...))
